<?php  

//Exit if accessed directly
if(!defined('ABSPATH')) {
    exit;
}

/*
* Format size units of a number.
*/
function ldg_formatSizeUnits($size) {
    $units = array('K', 'M', 'G', 'T');
    $currUnit = '';
    while (count($units) > 0  &&  $size > 1024) {
        $currUnit = array_shift($units);
        $size /= 1024;
    }
    return ($size | 0) . $currUnit;
}

/*
* Count the number of images in the media library.
*/
function ldg_img_count(){
        $query_img_args = array(
                'post_type' => 'attachment',
                'post_mime_type' =>array(
                                'jpg|jpeg|jpe' => 'image/jpeg',
                                'gif' => 'image/gif',
                                'png' => 'image/png',
                                ),
                'post_status' => 'inherit',
                'posts_per_page' => -1,
                );
        $query_img = new WP_Query( $query_img_args );
        return $query_img->post_count;
}

/*
* Count the total number of media items in the media library.
*/
function ldg_media_count(){
        $query_img_args = array(
                'post_type' => 'attachment',
                'post_status' => 'inherit',
                'posts_per_page' => -1,
                );
        $query_img = new WP_Query( $query_img_args );
        return $query_img->post_count;
}


/*
* List the themes found for this WordPress install.
*/
function ldg_list_themes() {
	echo "<strong>== Listed Themes ==</strong>\n";
	$all_themes = wp_get_themes( ); 
	$compare_theme = wp_get_theme();
	//Get the name of the active plugin for future reference.
	$compare_theme_name=$compare_theme->get( 'Name' );
	//Set a counter.
	$i=0;
	// Set text to indicate the active theme.
	foreach ( $all_themes as $theme => $theme_filename ) { 
		//Retrieve theme info for this row.
		$my_theme = wp_get_theme($theme);
		//Get theme name for this row.
		$my_theme_name=$my_theme->get( 'Name' );
		//Get theme version.
		$my_theme_version=$my_theme->get( 'Version' );
		//If the theme is active, this variable becomes the same as $test_active.
		$active_theme = ( $my_theme_name == $compare_theme_name ?  "[a] " : "[ ] ");
		//Write all the information for the theme from this row.
		echo "$active_theme$my_theme_name - Version $my_theme_version\n";
		//Increment the counter.
		$i++;
	}
		// Indicate the number of themes available in the themes folder.
		echo $i; ?> themes present.<?php echo "\n"; 

}

/*
* List the plugins found for this WordPress install.
*/
function ldg_list_plugins() {
// Check if get_plugins() function exists. This is required on the front end of the
// site, since it is in a file that is normally only loaded in the admin.
	if ( ! function_exists( 'get_plugins' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}
	
	$all_plugins = get_plugins();

	// Save the data to the error log so you can see what the array format is like. 
	echo "<strong>== Listed Plugins ==</strong>\n";
	
	$i=0;
	$j=0;
	foreach ($all_plugins as $this_plugin => $plugin_values) {
		//Determine whether this specific plugin is active.
		$test_active = "[a] ";
		$is_active = ( is_plugin_active($this_plugin) == true ? "[a] " : "[ ] " );
		//Increment $j if this plugin is active.
		$total_active = ( $is_active == $test_active ? $j++ : "" );
		// Get the name of the plugin.
		$this_plugin_name=$plugin_values['Name'];
		// Get the version of the plugin.
		$this_plugin_version=$plugin_values['Version'];
		// Display the plugin, it's version and whether it's active.
		echo "$is_active$this_plugin_name - Version $this_plugin_version\n";
		// Increment $i
		$i++;
	} 
	echo $j ." active plugins out of ".  $i . " present\n";
}

/*
* List the php extensions found for this WordPress install.
*/
function ldg_list_php_extensions() {

	$ldg_loaded_php_extensions = get_loaded_extensions();
	natcasesort($ldg_loaded_php_extensions);
	$i = 1;
	$j = 1;
	$ext_count = count($ldg_loaded_php_extensions); 
	echo "<strong>== PHP Extensions [ " . $ext_count . " Enabled ] ==</strong>\n" ;
	
	foreach ($ldg_loaded_php_extensions as $ldg_loaded_php_extension) {
		echo $ldg_loaded_php_extension;
		if ($i == 4 && $j < $ext_count) {
			echo  ",\n"; 
			$i=0;
		} else {
			if ($j == $ext_count) {
				echo "\n";
			} else {
				echo ", ";
			}
		}
		$i++;
		$j++;
	}
}


/*
* List the Web Server extensions found for this WordPress install.
*/
function ldg_list_apache_modules() {
	if (function_exists('apache_get_modules')) {
		$ldg_loaded_apache_modules = apache_get_modules();
		$i = 1;
		$j = 1;
		$apache_ext_count = count($ldg_loaded_apache_modules); 
		natcasesort($ldg_loaded_apache_modules); 
		echo "<strong>== Apache Extensions [ " . $apache_ext_count . " Enabled ] ==</strong>\n";
		
		foreach ($ldg_loaded_apache_modules as $ldg_loaded_apache_module) {
			echo $ldg_loaded_apache_module;
			if ($i == 3 && $j < $apache_ext_count) {
				echo  ",\n"; 
				$i=0;
			} else {
				if ($j == $apache_ext_count) {
					echo "\n";
				} else {
					echo ", ";
				}
			}
			$i++;
			$j++;
		}
	} else {
	echo "<strong>== Apache Module List Unavailable ==</strong>\n";
	$ldg_sapi_type = php_sapi_name();
			echo "   You're running PHP as ". $ldg_sapi_type. ".\n";
	}
}

/*
* List some general operating system configurations.
*/

function ldg_get_web_server_type() {
	global $is_apache, $is_IIS, $is_iis7, $is_nginx;
	$ldg_wst = '';
	if ($is_apache) {
		$ldg_wst = 'Apache';
	} else if ($is_IIS) {
		$ldg_wst = 'IIS';
	} else if ($is_iis7) {
		$ldg_wst = 'IIS7';
	} else if ($is_nginx) {
		$ldg_wst = 'Nginx';
	} else {
		$ldg_wst = 'Unknown';
	}
	return $ldg_wst;
}

function ldg_operating_system_config() {
	global $is_apache, $is_IIS, $is_iis7, $is_nginx, $wpdb, $required_php_version, $required_mysql_version;	
	echo "<strong>== Web Server and System Config ==</strong>\n"; 
	echo "Web Server Type: ". $ldg_web_server_type = ldg_get_web_server_type() ."\n";
	// echo "Apache: ". $is_apache ."\n"; 
	// echo "IIS: ". $is_IIS ."\n"; 
	// echo "IIS7: ". $is_iis7 ."\n"; 
	// echo "Nginx: ". $is_nginx ."\n"; 
	$ldg_dbVersion = $wpdb->db_version();
	$ldg_sapi_type = php_sapi_name();
	echo "= MySQL Version Information =\n"; 
	echo "  MySQL Database Version: " . $ldg_dbVersion ."\n";
	echo "  Min Req MySQL DB Version by WP: " . $required_mysql_version ."\n";
	echo "= PHP Version Information =\n"; 
	echo "  Web Server info according to PHP: \n";
	echo "    " . $ldg_software = $_SERVER['SERVER_SOFTWARE'] ."\n";
	echo "  Current PHP Version: ". $ldg_version = PHP_VERSION ."\n";
	echo "  Min Req PHP Version by WP: ". $required_php_version ."\n";
	echo "  PHP Memory Limit: " . ini_get('memory_limit')."\n";
	echo "  PHP Max Upload Size: " . ini_get( 'upload_max_filesize' )."\n";
	echo "  PHP Post Max Size: " . ini_get( 'post_max_size' )."\n"; 
	echo "  PHP SAPI: " . $ldg_sapi_type . ".\n";	}

/*
* General WordPress Configuration
*/
function ldg_WordPress_configurations() {
	echo "<strong>== WordPress Config ==</strong>\n";
	echo "Permalink Structure: ";
	if (get_option('permalink_structure') != "") {
		echo $ldg_permalink_structure = get_option('permalink_structure')."\n";
	} else {
		echo "undefined\n";
	}
	echo "Category Base: ";
	if (get_option('category_base') != "") {
		echo $ldg_category_base = get_option('category_base')."\n";
	} else {
		echo "undefined\n";
	}
	echo "Tag Base: ";
	if (get_option('tag_base') != "") {
		echo $ldg_tag_base = get_option('tag_base')."\n";
	} else {
		echo "undefined\n";
	}
	echo "WP Max Memory Limit: " . WP_MAX_MEMORY_LIMIT."\n";
	echo "WP Memory Limit: " . WP_MEMORY_LIMIT."\n";
	$ldg_max_upload_size = wp_max_upload_size();
	echo "WP Max Upload Size: " . ldg_formatSizeUnits($ldg_max_upload_size) ."\n";
	echo "WP Cache: ";
    if ( defined('WP_CACHE') ) {
	echo $ldg_wpcache = ( WP_CACHE == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "WP Debug: ";
    if ( defined('WP_DEBUG') ) {
	echo $ldg_wp_debug = ( WP_DEBUG == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "WP Debug Log: ";
    if ( defined('WP_DEBUG_LOG') ) {
	echo $ldg_debuglog = ( WP_DEBUG_LOG == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "WP Debug Display: ";
    if ( defined('WP_DEBUG_DISPLAY') ) {
	echo $ldg_debugdisplay = ( WP_DEBUG_DISPLAY == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "Display Errors: " . $ldg_displayerrors = ( ini_get('display_errors') == true ? "on" : "off" )."\n";
	echo "Log Errors: " . $ldg_logerrors = ( ini_get('log_errors') == true ? "on" : "off" )."\n";
	echo "Error Log Path: " . $ldg_errorlog = ini_get('error_log') ."\n";
	echo "Concatenate Scripts: ";
    if ( defined('CONCATENATE_SCRIPTS') ) {
	echo $ldg_concat = ( CONCATENATE_SCRIPTS == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "Allow Multisite: ";
    if ( defined('WP_ALLOW_MULTISITE') ) {
	echo $ldg_allowmultisite = ( WP_ALLOW_MULTISITE == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "Disable Auto Updates: ";
    if ( defined('AUTOMATIC_UPDATER_DISABLED') ) {
	echo $ldg_disable_auto_updates = ( AUTOMATIC_UPDATER_DISABLED == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 
	echo "Enable Core Updates: ";
    if ( defined('WP_AUTO_UPDATE_CORE') ) {
	echo $ldg_enable_auto_update_core = ( WP_AUTO_UPDATE_CORE == 'true' ? "on" : "off" )."\n"; 
	} else { echo "default*\n";  
	} 	
	echo "Disallow File Edit: ";
    if ( defined('DISALLOW_FILE_EDIT') ) {
	echo $ldg_disallow_file_edit = ( DISALLOW_FILE_EDIT == 'true' ? "disallowed" : "allowed" )."\n"; 
	} else { echo "default*\n";  
	} 	
	echo "Disallow File Mods: ";
    if ( defined('DISALLOW_FILE_MODS') ) {
	echo $ldg_disallow_file_mods = ( DISALLOW_FILE_MODS == 'true' ? "disallowed" : "allowed" )."\n"; 
	} else { echo "default*\n";  
	} 	
	echo "*default - not explicitly set in wp-config.php,\n";
	echo "so wp defaults apply.\n";
}

/*
* General site statistics (number of posts, pages, etc.
*/
function ldg_general_site_stats() {
	echo "<strong>== General Site Statistics ==</strong>\n";
	$ldg_total_pages = wp_count_posts('page'); 
	$ldg_total_posts = wp_count_posts('post');
	$ldg_total_comments = wp_count_comments();
	$ldg_total_users = count_users();
	$ldg_total_images = ldg_img_count();
	$ldg_total_media = ldg_media_count();
	foreach($ldg_total_users['avail_roles'] as $ldg_role => $ldg_count ) {
		echo ucfirst($ldg_role) . "s: " . $ldg_count . "\n";
	}
	echo "Total Users: " . $ldg_total_users['total_users']."\n";
	echo "Published Pages: " . $ldg_total_pages->publish ."\n";
	echo "Draft Pages: " . $ldg_total_pages->draft ."\n";
	echo "Published Posts: " . $ldg_total_posts->publish ."\n";
	echo "Draft Posts: " . $ldg_total_posts->draft ."\n";
	echo "Comments in Moderation: " . $ldg_total_comments->moderated ."\n";
	echo "Comments Approved: " . $ldg_total_comments->approved ."\n";
	echo "Comments Spam: " . $ldg_total_comments->spam ."\n";
	echo "Comments Trash: " . $ldg_total_comments->trash ."\n";
	echo "All Comments: " . $ldg_total_comments->total_comments ."\n";
	echo "Images: " . $ldg_total_images ."\n";
	echo "Other Media: " . ($ldg_total_media - $ldg_total_images) ."\n";
	echo "All Media: " . $ldg_total_media ."\n";
}


/*
* Stick together all the stats from the previous functions above.
*/
function ldg_get_the_info($ldgoptions) {
	echo "<strong>=== Diagnostic Glance ". LDG_PLUGIN_VERSION. " ===</strong>"."\n";
	echo "WordPress Version: ".get_bloginfo('version')."\n";
	if( $ldgoptions['listed_themes'] == 'show' || $ldgoptions['listed_plugins'] == 'show' ) {
	echo "Key: [a] = active, [ ] = not active \n";
	}
	echo ($ldgoptions['verbose_listing'] == 'show' ? 'Verbose listing: enabled<br /><br />' : '<br />');
	
	echo ($ldgoptions['listed_themes'] == 'show' ? ldg_list_themes().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== Listed Themes: hidden ==</strong><br/><br />'));
	echo ($ldgoptions['listed_plugins'] == 'show' ? ldg_list_plugins().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== Listed Plugins: hidden ==</strong><br/><br />'));
	echo ($ldgoptions['wp_configs'] == 'show' ? ldg_WordPress_configurations().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== WordPress Configs: hidden ==</strong><br/><br />'));
	echo ($ldgoptions['host_configs'] == 'show' ? ldg_operating_system_config().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== Host Configs: hidden ==</strong><br/><br />'));
	echo ($ldgoptions['php_exts'] == 'show' ? ldg_list_php_extensions().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== PHP Extensions: hidden ==</strong><br/><br />'));
	echo ($ldgoptions['apache_exts'] == 'show' ? ldg_list_apache_modules().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== Apache Modules: hidden ==</strong><br/><br />'));
	echo ($ldgoptions['site_stats'] == 'show' ? ldg_general_site_stats().'<br />' : ($ldgoptions['verbose_listing'] != 'show' ? '' : '<strong>== Site Statistics: hidden ==</strong><br/><br />'));
}


/*
* TODO: Future ajax configuration toggle interface.
*/
function ldg_list_widget_options($ldgoptions) {
	// easy icon inserts...
	$hidden_svg = '<img class="ldg-hidden-svg" width="15" title="hidden" alt="hidden" src="'. LDG_PLUGIN_URL .'images/eye-closed.svg" />';
	$visible_svg = '<img class="ldg-visible-svg" width="15" title="visible" alt="visible" src="'. LDG_PLUGIN_URL .'images/eye-open.svg" />';

	echo '<div class="ldg-options-key"><div class="inner"><strong>Key:</strong> <span class="ldg-option-visible">' . $visible_svg . '...section is visible</span> | <span class = "ldg-option-hidden">' . $hidden_svg . '...section is hidden</span></div>';
	echo '<div class="ldg-options-list">';
			foreach ($ldgoptions as $key => $value) {
				$ldghidden = ($value == 'show' ?  $visible_svg : $hidden_svg);
				$ldghiddenclass = ($value == 'show' ? 'ldg-option-visible' : 'ldg-option-hidden');
				$ldgsection = ucwords(str_replace("_", " ", $key));
				echo '<div class="ldg-options-item ' .$ldghiddenclass. '">' .$ldghidden. ' <strong>' .$ldgsection. '</strong></div>';
			} 
	echo '</div></div>';
}

/*
* Check to see if any widget options have been saved.
*/
function ldg_check_widget_options($ldgoptions) {
	$ready = false;
	$ready2 = 0;
	$ready3 = '';
	foreach ($ldgoptions as $key => $value) {
		$ready3 = ($value == 'show' ? $ready2 += 1  : '');
	} 
	$ready = ($ready2 > 0 ? true : false);
	if ($ready) {
		echo '';
	} else {
		echo '<div class="ldg-note"><strong>Note:</strong> <em>No sections have yet been selected.</em> Hover over the "Diagnostic Glance" dashboard title bar and click "Configure". Check some of the options boxes. Then click "Submit". For starters, consider selecting all items except "Site Stats" and "Verbose Listing". </div>';
	}
}

?>